==> VirtualBox-7.1.14.tar.bz2: VirtualBox-7.1.14/src/VBox/Additions/x11/x11include/xorg-server-1.4.2/dmxpixmap.h <==
/*
 * Copyright 2001-2004 Red Hat Inc., Durham, North Carolina.
 *
 * All Rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation on the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the
 * next paragraph) shall be included in all copies or substantial
 * portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NON-INFRINGEMENT.  IN NO EVENT SHALL RED HAT AND/OR THEIR SUPPLIERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

/*
 * Authors:
 *   Kevin E. Martin <kem@redhat.com>
 *
 */

/** \file
 * Interface for pixmap support.  \see dmxpixmap.c */

#ifndef DMXPIXMAP_H
#define DMXPIXMAP_H

#include "pixmapstr.h"

/** Pixmap private area. */
typedef struct _dmxPixPriv {
    Pixmap   pixmap;
    XImage  *detachedImage;
} dmxPixPrivRec, *dmxPixPrivPtr;


extern Bool      dmxInitPixmap(ScreenPtr pScreen);

extern PixmapPtr dmxCreatePixmap(ScreenPtr pScreen,
				 int width, int height, int depth);
extern Bool      dmxDestroyPixmap(PixmapPtr pPixmap);
extern RegionPtr dmxBitmapToRegion(PixmapPtr pPixmap);

extern void      dmxBECreatePixmap(PixmapPtr pPixmap);
extern Bool      dmxBEFreePixmap(PixmapPtr pPixmap);

/** Private index.  \see dmxpicmap.h \see dmxscrinit.c */
extern int dmxPixPrivateIndex;

/** Get pixmap private pointer. */
#define DMX_GET_PIXMAP_PRIV(_pPix)					\
    (dmxPixPrivPtr)(_pPix)->devPrivates[dmxPixPrivateIndex].ptr

#endif /* DMXPIXMAP_H */

==> VirtualBox-7.2.4.tar.bz2: VirtualBox-7.2.4/src/VBox/Additions/x11/x11include/xorg-server-1.8.0/dmxpixmap.h <==
/*
 * Copyright 2001-2004 Red Hat Inc., Durham, North Carolina.
 *
 * All Rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation on the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the
 * next paragraph) shall be included in all copies or substantial
 * portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NON-INFRINGEMENT.  IN NO EVENT SHALL RED HAT AND/OR THEIR SUPPLIERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

/*
 * Authors:
 *   Kevin E. Martin <kem@redhat.com>
 *
 */

/** \file
 * Interface for pixmap support.  \see dmxpixmap.c */

#ifndef DMXPIXMAP_H
#define DMXPIXMAP_H

#include "pixmapstr.h"

/** Pixmap private area. */
typedef struct _dmxPixPriv {
    Pixmap   pixmap;
    XImage  *detachedImage;
} dmxPixPrivRec, *dmxPixPrivPtr;


extern Bool      dmxInitPixmap(ScreenPtr pScreen);

extern PixmapPtr dmxCreatePixmap(ScreenPtr pScreen,
				 int width, int height, int depth,
				 unsigned usage_hint);
extern Bool      dmxDestroyPixmap(PixmapPtr pPixmap);
extern RegionPtr dmxBitmapToRegion(PixmapPtr pPixmap);

extern void      dmxBECreatePixmap(PixmapPtr pPixmap);
extern Bool      dmxBEFreePixmap(PixmapPtr pPixmap);

/** Private index.  \see dmxpicmap.h \see dmxscrinit.c */
extern DevPrivateKey dmxPixPrivateKey;

/** Get pixmap private pointer. */
#define DMX_GET_PIXMAP_PRIV(_pPix)					\
    (dmxPixPrivPtr)dixLookupPrivate(&(_pPix)->devPrivates, dmxPixPrivateKey)

#endif /* DMXPIXMAP_H */
